==> form_helper_widget-8.x-0.1.tar.gz: form_helper_widget/src/Form/FormHelperWidgetAddForm.php <==
<?php

namespace Drupal\form_helper_widget\Form;


use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\field_group\FieldgroupUi;
use Drupal\form_helper_widget\Services\FormHelperWidgetConf;

/**
 * Class FormHelperWidgetAddForm
 *
 * @package Drupal\form_helper_widget\Form
 */
class FormHelperWidgetAddForm extends FormBase {

  /**
   * The name of the entity type.
   *
   * @var string
   */
  protected $entityTypeId;

  /**
   * The entity bundle.
   *
   * @var string
   */
  protected $bundle;

  /**
   * The context for the group.
   *
   * @var string
   */
  protected $context;

  /**
   * The mode for the group.
   *
   * @var string
   */
  protected $mode;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'form_helper_widget.add';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $entity_type_id = NULL, $bundle = NULL, $context = NULL) {

    // Initialisation des données du contexte.
    $this->initContextData($form_state, $entity_type_id, $bundle, $context);

    $form += static::getFields([]);

    $form['submit'] = [
      '#type'        => 'submit',
      '#value'       => t('Save'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * Return the list of fiels of the form.
   *
   * @param array $defaultValues
   *   The defaultValues.
   *
   * @return mixed
   *   The form.
   */
  public static function getFields(array $defaultValues) {
    $form[FormHelperWidgetConf::FIELD_ID] = [
      '#type'          => 'textfield',
      '#title'         => t('Identifiant / valeur de la traduction par défaut'),
      '#default_value' => array_key_exists(FormHelperWidgetConf::FIELD_ID, $defaultValues) ? $defaultValues[FormHelperWidgetConf::FIELD_ID] : '',
      '#required'      => TRUE,
    ];

    $form[FormHelperWidgetConf::FIELD_DESCRIPTION] = [
      '#type'          => 'text_format',
      '#format'        => 'full_html',
      '#title'         => t('Description du champ'),
      '#required'      => TRUE,
      '#default_value' => array_key_exists(FormHelperWidgetConf::FIELD_DESCRIPTION, $defaultValues) ? $defaultValues[FormHelperWidgetConf::FIELD_DESCRIPTION]['value'] : '',
    ];

    $a=1;

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $widgetData = (object) array(
      FormHelperWidgetConf::FIELD_ID          => $form_state->getValue(FormHelperWidgetConf::FIELD_ID),
      FormHelperWidgetConf::FIELD_DESCRIPTION => $form_state->getValue(FormHelperWidgetConf::FIELD_DESCRIPTION),
      'mode'                                  => $this->mode,
      'entity_type'                           => $this->entityTypeId,
      'bundle'                                => $this->bundle,
      'context'                               => $this->context,
      'weight'                                => 20,
    );

    FormHelperWidgetConf::me()->saveWidget($widgetData);

    $form_state->setRedirectUrl($this->getReturnUrl($widgetData));
  }

  /**
   * Initialisation des données de contexte.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @param $entity_type_id
   * @param $bundle
   * @param $context
   */
  protected function initContextData(FormStateInterface $form_state, $entity_type_id, $bundle, $context) {

    $this->mode = \Drupal::request()->get('form_mode_name');
    if (empty($this->mode)) {
      $this->mode = 'default';
    }

    if (!$form_state->get('context')) {
      $form_state->set('context', $context);
    }
    if (!$form_state->get('entity_type_id')) {
      $form_state->set('entity_type_id', $entity_type_id);
    }
    if (!$form_state->get('bundle')) {
      $form_state->set('bundle', $bundle);
    }

    $this->entityTypeId = $form_state->get('entity_type_id');
    $this->bundle = $form_state->get('bundle');
    $this->context = $form_state->get('context');
  }

  /**
   * Retourn the fieldGroupUi url.
   *
   * @param $data
   *
   * @return \Drupal\Core\Url
   */
  protected function getReturnUrl($data) {
    return FieldgroupUi::getFieldUiRoute($data);
  }


}

==> form_helper_widget-8.x-0.3.tar.gz: form_helper_widget/src/Form/FormHelperWidgetAddForm.php <==
<?php

namespace Drupal\form_helper_widget\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_group\FieldgroupUi;
use Drupal\form_helper_widget\Services\FormHelperWidgetConf;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class FormHelperWidgetAddForm.
 *
 * @package Drupal\form_helper_widget\Form
 */
class FormHelperWidgetAddForm extends FormBase {

  use StringTranslationTrait;

  /**
   * The name of the entity type.
   *
   * @var string
   */
  protected $entityTypeId;

  /**
   * The entity bundle.
   *
   * @var string
   */
  protected $bundle;

  /**
   * The context for the group.
   *
   * @var string
   */
  protected $context;

  /**
   * The mode for the group.
   *
   * @var string
   */
  protected $mode;

  /**
   * Request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * Class constructor.
   */
  public function __construct(Request $request) {
    $this->request = $request;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'form_helper_widget.add';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $entity_type_id = NULL, $bundle = NULL, $context = NULL) {

    // Initialisation des données du contexte.
    $this->initContextData($form_state, $entity_type_id, $bundle, $context);

    $form += static::getFields([]);

    $form['submit'] = [
      '#type'        => 'submit',
      '#value'       => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * Return the list of fiels of the form.
   *
   * @param array $defaultValues
   *   The defaultValues.
   *
   * @return mixed
   *   The form.
   */
  public static function getFields(array $defaultValues) {
    $form[FormHelperWidgetConf::FIELD_ID] = [
      '#type'          => 'textfield',
      '#title'         => t('Identifiant / valeur de la traduction par défaut'),
      '#default_value' => array_key_exists(FormHelperWidgetConf::FIELD_ID, $defaultValues) ? $defaultValues[FormHelperWidgetConf::FIELD_ID] : '',
      '#required'      => TRUE,
    ];

    $form[FormHelperWidgetConf::FIELD_DESCRIPTION] = [
      '#type'          => 'text_format',
      '#format'        => 'full_html',
      '#title'         => t('Description du champ'),
      '#required'      => TRUE,
      '#default_value' => array_key_exists(FormHelperWidgetConf::FIELD_DESCRIPTION, $defaultValues) ? $defaultValues[FormHelperWidgetConf::FIELD_DESCRIPTION]['value'] : '',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $widgetData = (object) [
      FormHelperWidgetConf::FIELD_ID          => $form_state->getValue(FormHelperWidgetConf::FIELD_ID),
      FormHelperWidgetConf::FIELD_DESCRIPTION => $form_state->getValue(FormHelperWidgetConf::FIELD_DESCRIPTION),
      'mode'                                  => $this->mode,
      'entity_type'                           => $this->entityTypeId,
      'bundle'                                => $this->bundle,
      'context'                               => $this->context,
      'weight'                                => 20,
    ];

    FormHelperWidgetConf::me()->saveWidget($widgetData);

    $form_state->setRedirectUrl($this->getReturnUrl($widgetData));
  }

  /**
   * Init the context data.
   *
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The formstate.
   * @param string $entity_type_id
   *   The entity Type Id.
   * @param string $bundle
   *   The bundle.
   * @param string $context
   *   The context.
   */
  protected function initContextData(FormStateInterface $form_state, $entity_type_id, $bundle, $context) {
    $this->mode = $this->request->get('form_mode_name');
    if (empty($this->mode)) {
      $this->mode = 'default';
    }

    if (!$form_state->get('context')) {
      $form_state->set('context', $context);
    }
    if (!$form_state->get('entity_type_id')) {
      $form_state->set('entity_type_id', $entity_type_id);
    }
    if (!$form_state->get('bundle')) {
      $form_state->set('bundle', $bundle);
    }

    $this->entityTypeId = $form_state->get('entity_type_id');
    $this->bundle = $form_state->get('bundle');
    $this->context = $form_state->get('context');
  }

  /**
   * Retourn the fieldGroupUi url.
   *
   * @param mixed $data
   *   The group to get the field ui route for.
   *
   * @return \Drupal\Core\Url
   *   The url.
   */
  protected function getReturnUrl($data) {
    return FieldgroupUi::getFieldUiRoute($data);
  }

}
